Native
Structs
- Header
Map - A specialized multimap for header names and values.
- Header
Name - Represents an HTTP header field name
- Header
Value - Represents an HTTP header field value.
- WebSocket
Config - The configuration for WebSocket connection.
- WebSocket
Stream - A wrapper around an underlying raw stream which implements the WebSocket protocol.
Enums
- Error
- Message
- An enum representing the various forms of a WebSocket message.
- Role
- Indicates a Client or Server role of the websocket
Functions
- accept_
async - Accepts a new WebSocket connection with the provided stream.
- accept_
async_ with_ config - The same as
accept_async()but the one can specify a websocket configuration. Please refer toaccept_async()for more details. - connect
- connect_
with_ headers - Connect with additional HTTP headers in the WebSocket upgrade request.