Module native

Module native 

Native

Structs

HeaderMap
A specialized multimap for header names and values.
HeaderName
Represents an HTTP header field name
HeaderValue
Represents an HTTP header field value.
WebSocketConfig
The configuration for WebSocket connection.
WebSocketStream
A wrapper around an underlying raw stream which implements the WebSocket protocol.

Enums

Error
Message
An enum representing the various forms of a WebSocket message.
Role
Indicates a Client or Server role of the websocket

Functions

accept_async
Accepts a new WebSocket connection with the provided stream.
accept_async_with_config
The same as accept_async() but the one can specify a websocket configuration. Please refer to accept_async() for more details.
connect
connect_with_headers
Connect with additional HTTP headers in the WebSocket upgrade request.