Module native

Module native 

Native

Structs

HeaderMap
A specialized multimap for header names and values.
HeaderName
Represents an HTTP header field name
HeaderValue
Represents an HTTP header field value.
WebSocketStream
A wrapper around an underlying raw stream which implements the WebSocket protocol.

Enums

Error
Message
An enum representing the various forms of a WebSocket message.

Functions

accept
connect
connect_with_headers
Connect with additional HTTP headers in the WebSocket upgrade request.
take_upgraded
Take an already upgraded websocket connection